OMFIT is an integrated modeling and experimental data analysis software for magnetically confined thermonuclear fusion experiments.
The goal of OMFIT is to enhance existing scientific workflows and enable new integrated modeling capabilities.

To achieve these goals OMFIT adopts a bottom-up collaborative development approach.

For more info and tutorials visit the OMFIT `documentation website <https://omfit.io>`_ .

The OMFIT source code is maintained as a `GitHub repository <https://github.com/gafusion/OMFIT-source>`_ .
Fill out the OMFIT users agreement `OMFIT users agreement form <http://form.omfit.io>`_ to be added to the GitHub repository or the mailing list.
The GitHub `issue tracking system <https://github.com/gafusion/OMFIT-source/issues?state=open>`_ is the best way to file bug reports and make feature requests.

OMFIT users and developers are welcome to join the OMFIT `DISCORD server <https://discord.gg/ARDn3qD7CE>`_.
